from setuptools import setup

setup(name='stat-gaussian-binomial-distributions',
      version='0.1',
      description='Gaussian distributions and binomial distributions',
      packages=['stat-gaussian-binomial-distributions'],
      author="gns",
      zip_safe=False)
